#
# spec file for package pesign
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pesign
Version:        0.109
Release:        11.11
Summary:        Signing tool for PE-COFF binaries
License:        GPL-2.0
Group:          Productivity/Security
Url:            https://github.com/vathpela/pesign
Source:         %{name}-%{version}.tar.gz
# PATCH-FIX-SUSE pesign-suse-build.patch glin@suse.com -- Adjust Makefile for the build service
Patch1:         pesign-suse-build.patch
# PATCH-FIX-UPSTREAM pesign-fix-build-errors.patch glin@suse.com -- Fix gcc warnings
Patch2:         pesign-fix-build-errors.patch
# PATCH-FIX-UPSTREAM pesign-privkey_unneeded.diff glin@suse.com -- Don't check the private key when importing the raw signature
Patch3:         pesign-privkey_unneeded.diff
# PATCH-FIX-UPSTREAM pesign-clear-padding-bits.patch glin@suse.com -- Clear the allocated space before inserting the certificate list
Patch4:         pesign-clear-padding-bits.patch
# PATCH-FIX-SUSE use-standard-pid-location.patch p.drouand@gmail.com --Use standard /run instead of /var/run for pidfile
Patch6:         use-standard-pid-location.patch
# PATCH-FIX-UPSTREAM pesign-no-db.patch glin@suse.com -- Allow some commands to proceed without a NSS database
Patch7:         pesign-no-db.patch
# PATCH-FIX-SUSE pesign-run.patch aj@suse.com - Use /run instead of /var/run
Patch8:         pesign-run.patch
# PATCH-FIX-UPSTREAM pesign-enable-supplementary-programs.patch glin@suse.com -- Fix and enable the supplementary programs
Patch9:         pesign-enable-supplementary-programs.patch
BuildRequires:  mozilla-nss-devel
BuildRequires:  pkg-config
BuildRequires:  popt-devel
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
PreReq:         pwdutils
ExclusiveArch:  ia64 %ix86 x86_64

%description
Signing tool for PE-COFF binaries, hopefully at least vaguely compliant
with the PE and Authenticode specifications.



Authors:
--------
    Peter Jones <pjones@redhat.com>

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1

%build
make OPTFLAGS="$RPM_OPT_FLAGS"

%install
make INSTALLROOT=%{buildroot} PREFIX=/usr DOCDIR=/share/doc/packages install
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/lib/pesign

mkdir -p $RPM_BUILD_ROOT%{_sbindir}
make INSTALLROOT=%{buildroot} UNITDIR=%{_unitdir} install_systemd

# there's some stuff that's not really meant to be shipped yet
rm -rf %{buildroot}/boot %{buildroot}/usr/include
rm -rf %{buildroot}%{_libdir}/libdpe*

%pre
getent group pesign >/dev/null || groupadd -r pesign
getent passwd pesign >/dev/null || useradd -r -g pesign -d /var/lib/pesign -s /bin/false -c "PE-COFF signing daemon" pesign
%service_add_pre pesign.service

%preun
%service_del_preun pesign.service

%post
%service_add_post pesign.service
systemd-tmpfiles --create /usr/lib/tmpfiles.d/pesign.conf

%postun
%service_del_preun pesign.service

%files
%defattr(-,root,root)
%doc COPYING
%{_bindir}/pesign
%{_bindir}/pesign-client
%{_bindir}/efikeygen
%{_bindir}/pesigcheck
%{_bindir}/efisiglist
%{_bindir}/authvar
%dir %{_sysconfdir}/popt.d
%config %{_sysconfdir}/popt.d/pesign.popt
%{_sysconfdir}/pki/
%config %{_sysconfdir}/rpm/macros.pesign
%{_mandir}/man?/*
/var/lib/pesign
%{_unitdir}/pesign.service
/usr/lib/tmpfiles.d/pesign.conf
%dir %attr(0775,pesign,pesign) %{_sysconfdir}/pki/pesign
%ghost %dir %attr(0770,pesign,pesign) /run/%{name}
%dir %attr(0770,pesign,pesign) %{_localstatedir}/lib/%{name}

%changelog
* Tue Jul  1 2014 glin@suse.com
- Update pesign-enable-supplementary-programs.patch to fix write
  loop
* Thu Jun 12 2014 glin@suse.com
- Add pesign-enable-supplementary-programs.patch to fix and enable
  the supplementary programs: pesigcheck, authvar, efisiglist
* Wed Apr 16 2014 aj@suse.com
- Add pesign-run.patch: Use /run instead of /var/run (bnc#873857).
* Fri Jan 31 2014 lnussel@suse.de
- mark dir in /var/run as %%ghost
* Thu Nov  7 2013 glin@suse.com
- Add pesign-no-db.patch to allow some commands to proceed without
  a NSS database.
* Thu Oct 24 2013 glin@suse.com
- Revert the dowload Url since it's not valid
* Tue Oct 22 2013 p.drouand@gmail.com
- Update to version 0.109
- Remove sysvinit related old stuff
- Remove redundant %%clean section
- Add use-standard-pid-location.patch
  Use the good location to stock pidfile
- Use download Url as source
- Rebase pesign-suse-build.patch to upstream changes as it has been
  partially merged on upstream
- Remove pesign-allow-no-issuer-cert.patch; fixed on upstream
* Thu Jul 18 2013 glin@suse.com
- Add pesign-allow-no-issuer-cert.patch to avoid crash when the
  issuer's certificate is not available
* Tue Jul  9 2013 glin@suse.com
- Update to 0.106
- Add pesign-clear-padding-bits.patch to clear the padding bits
- Rebase patches:
  + pesign-suse-build.patch
  + pesign-fix-build-errors.patch
  + pesign-privkey_unneeded.diff
- Drop upstreamed patches
  + pesign-client-initialize-action.patch
  + pesign-bnc808594-align-signatures.patch
  + pesign-upstream-fixes.patch
  + pesign-fix-export-attributes.patch
  + pesign-no-set-image-size.patch
  + pesign-client-read-pin-file.patch
  + pesign-local-database.patch
  + pesign-bnc801653-teardown-segfault.patch
  + pesign-bnc805166-fix-signature-list.patch
* Tue Mar 26 2013 glin@suse.com
- Add pesign-bnc808594-align-signatures.patch to align signatures
  (bnc#808594, bnc#811325)
* Fri Mar  1 2013 glin@suse.com
- Update pesign-bnc805166-fix-signature-list.patch to avoid the
  potential crash when inserting a signature (bnc#805166)
- Add pwdutils to PreReq
* Mon Feb 25 2013 glin@suse.com
- Update pesign-bnc805166-fix-signature-list.patch to skip the
  unneeded private key request. (bnc#805166c#17)
* Sat Feb 23 2013 jlee@suse.com
- Modified pesign-bnc805166-fix-signature-list.patch, block out the
  source code for find/attach Issuer certificate
  (bnc#805166 comment#13)
* Fri Feb 22 2013 glin@suse.com
- Add pesign-bnc805166-fix-signature-list.patch to fix the broken
  signature list when inserting signature into a signed EFI binary
  (bnc#805166)
* Tue Feb 12 2013 mls@suse.de
- do not try to recalculate the image size, it is included in the
  hash and therefore must not change.
* Wed Feb  6 2013 glin@suse.com
- Merge patches for FATE#314552
  + pesign-fix-export-attributes.patch: fix crash when exporting
    the signed attributes
  + pesign-privkey_unneeded.diff: Don't check the private key when
    importing the raw signature
- Add pesign-bnc801653-teardown-segfault.patch to fix crash when
  freeing digests (bnc801653)
- Drop pesign-digestdata.diff which is no longer needed.
* Mon Jan 21 2013 glin@suse.com
- Add pesign-digestdata.diff to generate digestdata (FATE#314552)
* Wed Dec 12 2012 fcrozat@suse.com
- Don't call sysv RPM post/pre macros when building for systemd
- Ship rcpesign for systemd, link to /sbin/service
- Update pesign-suse-build.patch to allow change systemd unit
  install directory.
- Don't hardcode systemd unit directory, since it changed in
  Factory.
* Tue Dec 11 2012 glin@suse.com
- Add Requires: pwdutils
* Wed Nov 28 2012 glin@suse.com
- Add pesign-local-database.patch to support the local certificate
  database
- Amend the spec file to build on openSUSE:Factory
* Thu Nov  8 2012 glin@suse.com
- Version bump to 0.99 (FATE#314484)
  + Add documentation for --daemonize and --nofork
  + Make popt aliases work
  + Add documentation for pesign-client
  + Add --pinfd and --pinfile to the client
- Update pesign-suse-build.patch and pesign-fix-build-errors.patch
- Add pesign-upstream-fixes.patch to backport fixes from git head
  and add sysvinit script
- Add pesign-client-initialize-action.patch to initialize client
  action to avoid undetermined flags.
- Add pesign-client-read-pin-file.patch to fix pin file reading
* Mon Oct 15 2012 glin@suse.com
- Version bump to 0.98
  + close the socket immediately on invalid input
  + Slightly better error messages
  + Log an error if digest initialization fails
  + Add systemd bits for pesignd
  + Add actual signing code to the daemon
  + Add input and output setup for sign functionality in the daemon
  + Audit allocation of CERTCertificateList/PK11SlotList and
    friends
  + Fix memory leaks
- Refresh pesign-suse-build.patch and pesign-fix-build-errors.patch
* Mon Aug 13 2012 glin@suse.com
- Version bump to 0.9
  + Add NSS "token" support for smartcards.
  + Allocate space for the section header variable
- Refresh pesign-fix-build-errors.patch to fix the warning
- Drop upstreamed pesign-allocate-shdr.patch
* Fri Aug 10 2012 glin@suse.com
- Add pesign-allocate-shdr.patch to allocate space for the section
  header variable
* Thu Aug  9 2012 glin@suse.com
- Version bump to 0.8
  + Don't open the DB r/w, read-only is fine.
  + Attempt to do a better job setting the image size.
  + Emit correct OID for encryption type.
- Drop pesign-fix-image-size.patch which is already in 0.8
* Tue Aug  7 2012 glin@suse.com
- Add upstream patch pesign-fix-image-size.patch to set the image
  size correctly.
- Drop pesign-elilo-workaround.patch
* Mon Aug  6 2012 glin@suse.com
- Version bump to 0.7
  + Fix incorrect initialization error in (undocumented) -e option.
  + Use SEC_OID_PKCS1_RSA_ENCRYPTION like MS
  + Initialize the index variable of loop
  + Adjust the buffer size to avoid overflow
  + Make sure pe_populatecert() always returns a value
* Mon Jul 23 2012 glin@suse.com
- Add pesign-elilo-workaround.patch to workaround the section
  header corruption in some EFI image (elilo for example)
* Mon Jul 23 2012 glin@suse.com
- Add pesign-fix-build-errors.patch to fix build error/warning
- Don't install the util efi images
- Fix the RPM_OPT_FLAGS warning
* Thu Jul 12 2012 glin@suse.com
- Version bump to 0.5
  + Handle and report mremap() failure
  + Man page should be in section 1.
  + Add some basic signature list management.
  + Add some more efi-defined constants, flesh out efi_guid_t.
  + authver: Find a guid for 'namespace'.
  + Add some basic ucs2 functions :(
  + Support multiple signatures correctly.
  + Add ascii_to_ucs2()
  + Add file formats and some code for variables-on-disk.
  + Allow the memory map to move when we're allocating space in the
    binary.
  + Remove extra call to ftruncate()
  + Adjust section addresses when we remap the pecoff binary.
  + Correctly set win_certificate.length to /include/
    win_certificate.
  + Move certificate space iterator to wincert.c so other stuff can
    get it.
  + Split allocating space for certs and filling it in.
  + Put the new signature into the cms ctx instead of keeping it
    locally.
  + Actually calculate space and extend the file before hashing the
    binary.
  + Bounds-check everything we're hashing so we don't segfault on a
    bad bin.
- Add pesign-always-return-value.patch to fix
  no-return-in-nonvoid-function
- Drop upsreamed patch pesign-mem-reallocation.patch
* Fri Jun 29 2012 glin@suse.com
- Add pesign-mem-reallocation.patch to fix crash when writing
  signature
* Tue Jun 26 2012 glin@suse.com
- Version bump to 0.3
  + it seems to generate working signatures
* Thu Jun 21 2012 glin@suse.com
- New package pesign 0.2
